Support Vector Machines (SVM) {#tutorial_py_svm_index}
=============================

-   @subpage tutorial_py_svm_basics

    Get a basic understanding of what SVM is

-   @subpage tutorial_py_svm_opencv

    Let's use SVM functionalities in OpenCV
